==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Ordna</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Flytta längst fram</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Flytta framåt</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Flytta bakåt</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Flytta längst bak</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Markera detta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Allmänna Inställningar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Bildinställningar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Färg</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfärg</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Räkneverk</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fördunklingsfaktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Objektskugga</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Objektinställningar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Stäng andra</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Stäng alla</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Stäng alla till vänster</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Stäng alla till höger</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Verktygsval</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktiverat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Tillämpa</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Kant- och fyllnadssynlighet</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Kantlinje och fyllning</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Kantlinje och ingen fyllning</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Ingen kantlinje och ingen fyllning</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Teckenstorlek</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Understruken</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Bildeffekter</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Ingen effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Skugga</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Gråskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kantlinje</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertera färg</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Begränsad</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Vid aktivering tvingas arbetsytan
att inkludera bakgrundsbilden.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Tillämpa</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Färg:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Arbetsytans bakgrundsfärg</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotera bilden</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° medurs</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° moturs</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Slumpmässig</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Positiva värden roterar medurs, negativa värden moturs.
Rotation med annat än 90°-multiplikator kan leda till kvalitetsförlust.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontellt</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikalt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotera</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Vänd</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skala bild</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Bevara proportioner</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredd:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höjd:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Dekal</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Markera</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Siffra</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Rektangelmarkering</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Ellipsmarkering</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Överstrykningspenna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dubbelpil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Oskärpa</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummerpekare</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Dekal</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelera</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Textpekare</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Textpil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Sifferpil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zooma in (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zooma ut (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Återställ zoom (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Ordna</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Flytta längst fram</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Flytta framåt</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Flytta bakåt</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Flytta längst bak</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Markera detta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Allmänna Inställningar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Bildinställningar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Färg</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Textfärg</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Räkneverk</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Fördunklingsfaktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Objektskugga</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Objektinställningar</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacitet</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Stäng andra</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Stäng alla</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Stäng alla till vänster</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Stäng alla till höger</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Verktygsval</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktiverat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Upprepa</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Beskär</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotera</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Ändra arbetsytan</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Tillämpa</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Vertikalt</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontell</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Tillämpa</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Kant- och fyllnadssynlighet</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Kantlinje och fyllning</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Kantlinje och ingen fyllning</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Ingen kantlinje och ingen fyllning</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Teckenstorlek</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Understruken</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Bildeffekter</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Ingen effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Skugga</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Gråskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kantlinje</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertera färg</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Begränsad</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Vid aktivering tvingas arbetsytan
att inkludera bakgrundsbilden.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Tillämpa</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Färg:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Arbetsytans bakgrundsfärg</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotera bilden</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° medurs</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° moturs</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Slumpmässig</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Positiva värden roterar medurs, negativa värden moturs.
Rotation med annat än 90°-multiplikator kan leda till kvalitetsförlust.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontellt</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikalt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotera</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Vänd</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skala bild</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Bevara proportioner</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredd:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höjd:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Dekal</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Markera</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Siffra</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Rektangelmarkering</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Ellipsmarkering</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Överstrykningspenna</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dubbelpil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Oskärpa</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummerpekare</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Dekal</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelera</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Textpekare</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Textpil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Sifferpil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicera</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zooma in (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zooma ut (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Återställ zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Återställ zoom</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Anpassa bild</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Anpassa bild till vyn (%1)</translation>
    </message>
</context>
</TS>
